pub struct MaterialSource {
pub albedo: [f32; 4],
pub roughness: f32,
pub metallic: f32,
pub unlit: f32,
pub texture_source: Option<String>,
}Expand description
Pure data description of a material, used by scene loaders.
Fields
albedo: [f32; 4]roughness: f32metallic: f32unlit: f32texture_source: Option<String>Trait Implementations
Sourceimpl Clone for MaterialSource
impl Clone for MaterialSource
Sourcefn clone(&self) -> MaterialSource
fn clone(&self) -> MaterialSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterialSource
impl Debug for MaterialSource
Sourceimpl<'de> Deserialize<'de> for MaterialSource
impl<'de> Deserialize<'de> for MaterialSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MaterialSource
impl PartialEq for MaterialSource
Sourcefn eq(&self, other: &MaterialSource) -> bool
fn eq(&self, other: &MaterialSource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MaterialSource
impl Serialize for MaterialSource
impl Component for MaterialSource
impl StructuralPartialEq for MaterialSource