pub struct MeshSource(pub String);Expand description
A string-based identifier pointing to a mesh asset, used by scene loaders to request mesh loading.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for MeshSource
impl Clone for MeshSource
Sourcefn clone(&self) -> MeshSource
fn clone(&self) -> MeshSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeshSource
impl Debug for MeshSource
Sourceimpl<'de> Deserialize<'de> for MeshSource
impl<'de> Deserialize<'de> for MeshSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MeshSource
impl PartialEq for MeshSource
Sourcefn eq(&self, other: &MeshSource) -> bool
fn eq(&self, other: &MeshSource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MeshSource
impl Serialize for MeshSource
impl Component for MeshSource
impl StructuralPartialEq for MeshSource